Coverage for /Users/davegaeddert/Developer/dropseed/plain/plain-oauth/plain/oauth/migrations/0005_alter_oauthconnection_unique_together_and_more.py: 100%

1# Generated by Plain 0.3.0 on 2024-08-16 16:46

2

3 from plain import models

4 from plain.models import migrations

5

6

7 class Migration(migrations.Migration):

8 dependencies = [

9 ("users", "__first__"),

10 ("plainoauth", "0004_alter_oauthconnection_access_token_and_more"),

11 ]

12

13 operations = [

14 migrations.AddConstraint(

15 model_name="oauthconnection",

16 constraint=models.UniqueConstraint(

17 fields=("provider_key", "provider_user_id"),

18 name="unique_oauth_provider_user_id",

19 ),

20 ),

21 ]